# pyFGS Configuration
isHospital = 1
isAssoc = 0

# language used for giving instructions (currently available: english|german)
#language = "english"
language = "german"

if language == "english":
  lang_suffix = ""
else:
  lang_suffix = "_" + language


# Global Settings:
INPUT_MODE = 1
TEXT_SIZE_SMALL = 4
TEXT_SIZE_BIG = 15
PICTURE_SIZE = .33

#various intervals in the trial (in ms)
# delay before orienting stimulus (+/- jitter)
D1 = 400
# length of presentation of orienting stimuli
D2 =1000
# delay after orienting stimuli (+/- jitter)
D3 =200
# uniform random jitter parameter (+/- N ms)
JITTER =75
# presentation time for an item in the list
PR  =700 
# inter-stimulus interval (+/- jitter)
ISI = 275
# mean delay before probe (+/- jitter)
D4 =3000
# post-trial pause
D5 = 500
# pre-probe delay jitter
JITTER2 = 300
# max presentation time
MAXP = 100000000
# screen background color
backgroundcol = (0.84,0.84,0.84)
textSize = 0.05
# the secret key the experimenter has to press to move from practice to real trials
endPracticeKey = "F2"
endBlockKey = "P"

# keyboard mappings
targetKey = "."
lureKey = ","

# stimulus size specification
POOLSIZE = 16

# number of sessions for each subject
numSessions = 2

# instructions that should be given at the beginning of each session
instructions = open("intro_hosp" + lang_suffix + ".txt").read()

# make the stimulus pools
faceStimuli = ImagePool("wilsonfaces_xpm", PICTURE_SIZE)
gratingStimuli = ImagePool("gratingimagesx", PICTURE_SIZE)
letterStimuli = TextPool("letter-pool.txt",.1,(0,0,0))
wordStimuli = TextPool("word-pool.txt", .1, (0,0,0))
		
# get the blocklist for this subject
blockBase = "lists/hospitalBlock1_"

def readBlocks(rangeNum,blockBase):
   import random
   listInd = random.randint(0,4)
   # depending on the session, get the range
   if rangeNum==1:
      listInd = listInd + 5
   blockF = blockBase + str(listInd) + ".txt"
   print blockF
   f = open(blockF,'r')
   blks= Pool()
   ln = f.readline()
   blockN = -1
   while not ln=='':
       if ln[0]=='*':
           # save the last block
           if blockN != -1:
               blks[blockN].seq = thisBlock
           blockN = blockN +1
           # add a new block to the blocks object
           thisBlock = []
           # read mode and practice/real
           inf = ln[1:].split()
           infNum = []
           for x in inf:
               infNum.append(int(x))
           # now the first number in infNum is the mode and the second
           # one determines whether the block is practice or real 
           if infNum[0]==1:
               thisMode = 'FACE'
           elif infNum[0]==2:
               thisMode = 'GRATING'
           else:
               thisMode = 'LETTER'
           # append the basic info of the new block to the list
           blks.append(PoolDict(num=(blockN+1), seq = [],mode=thisMode,feedback=infNum[2],ispractice = infNum[1]))
       else:
           # the line is just a list and hence can be appended to this block
           wrds = ln.split()
           lst = []
           for x in wrds:
               lst.append(int(x))
           thisBlock.append(lst)
       # read the next line
       ln = f.readline()
   # now also save the last block
   blks[blockN].seq=thisBlock
   f.close()
   return blks

blocks = []
# modification of session-specific variables, using a Sequence
seq = Sequence(numSessions)
blockOrder = range(numSessions)
import random
random.shuffle(blockOrder)
seq[0].blocks = readBlocks(blockOrder[0]+1,blockBase)
seq[1].blocks = readBlocks(blockOrder[1]+1,blockBase)
seq[0].numBlocks = len(seq[0].blocks)
seq[1].numBlocks = len(seq[1].blocks)

modeStimDict = {'FACE':faceStimuli, 'GRATING':gratingStimuli, 'LETTER':letterStimuli, 'WORD':wordStimuli}
