function ERP_TLiEEG(subject,chan)
% create ERPS for targets and lures for a selected set of
% electrodes in iEEG data
% INPUT Args
% subject = 'FR320';
% chan = 20
% (this assumes the iEEG data directory is /data/eeg and events are
% in beh/events.mat)

%figure out the line noise filter
if strcmp(subject(1:2),'FR')
  filterFreq = [48 52];
else
  filterFreq = [58 62];
end

% set the durations
offsetMS = -125;
durationMS = 1000-offsetMS;
bufferMS = 500;
relativeMS = [offsetMS 0];

basedir = '/data/eeg';
%get the events for targets & lures; faces & gratings
evs = loadEvents(fullfile(basedir,subject,'beh/events.mat'));
cueEvs = filterStruct(evs,'~strcmp(eegfile,'''') & strcmp(type,''CUE'')');
targFEvs = filterStruct(cueEvs,'istarget & strcmp(mode,''FACE'')');
lureFEvs = filterStruct(cueEvs,'~istarget & strcmp(mode,''FACE'')');
targLEvs = filterStruct(cueEvs,'istarget & strcmp(mode,''LETTER'')');
lureLEvs = filterStruct(cueEvs,'~istarget & strcmp(mode,''LETTER'')');

% convert ms times into samples
samplerate = GetRateAndFormat(evs(1));
offset = samplerate*(offsetMS/1000);
duration = samplerate*(durationMS/1000);
buffer = samplerate*(bufferMS/1000);
relative = samplerate.*(relativeMS./1000);

% plot the actual ERPs
erpFT = erp(chan,targFEvs,duration,offset,buffer,relative, ...
	    filterFreq,'stop',1,5);
erpFL = erp(chan,lureFEvs,duration,offset,buffer,relative, ...
	    filterFreq,'stop',1,5);
erpLT = erp(chan,targLEvs,duration,offset,buffer,relative, ...
	    filterFreq,'stop',1,5);
erpLL = erp(chan,lureLEvs,duration,offset,buffer,relative, ...
	    filterFreq,'stop',1,5);
timevec= offsetMS:(1000/samplerate):(durationMS+offsetMS);

% sometimes due to division errors the length of the time vector
% does not match the length of the ERP. Here we correct that.
if length(timevec) ~= length(erpFT)
  timevec = timevec(1:length(erpFT));
end

figure(1)
plot(timevec,erpFT,'LineWidth',3);
hold on
plot(timevec,erpFL','r','LineWidth',3);
hold off
xlabel('time (ms)');
ylabel('amplitude (\muV)');
legend('target','lure','Location','NorthWest');
publishfig
title('FACE','FontSize',20);

figure(2)
plot(timevec,erpLT,'LineWidth',3);
hold on
plot(timevec,erpLL','r','LineWidth',3);
hold off
xlabel('time (ms)');
ylabel('amplitude (\muV)');
legend('target','lure','Location','NorthWest');
publishfig
title('LETTER','FontSize',20);
