function addPracticeFaces(filename)
% function addPracticeFaces(filename)
% This function adds blocks of practice faces to the existing file
% with stimuli for the experiment. These practice trials have list
% length one and the goal is to simply familiarize the subject with
% the faces.

rand('seed',sum(100*clock)); %reset the random number generator

% open file
if exist(filename,'file')
  fid = fopen(filename,'a');
else
  fid = fopen(filename,'w');
end
fprintf(fid,sprintf('* %d %d %d\n',1,1,1));

Ntrials = 48; %this should take about 6 minutes; each face is shown
              %3*2=6 times; Ntrials has to be a multiple of 16
Ntargets = 16;
Nlures = Ntrials-Ntargets;
	      
% we make targets appear 1/3 of the time and lures 2/3
targPerm = randperm(Ntargets);
trialPerm = randperm(Ntrials);

% randomly determine the order in which targets appear (targPerm)
% and on what positions in the list (trialPerm)
trialList(trialPerm(1:Ntargets)) = targPerm;
probeList(trialPerm(1:Ntargets)) = targPerm;

% now fill the rest of the trials with lures
NlureBlocks = Nlures/16;
for n =1:NlureBlocks
  OK = 0;
  while ~OK
    lurePerm = randperm(16);
    probePerm = randperm(16);
    % we don't want the lure to equal the stimulus shown in that trial
    if isempty(find(lurePerm==probePerm))
      OK = 1;
    end
  end
  trialList(trialPerm((n*16+1):(n+1)*16)) = lurePerm;
  probeList(trialPerm((n*16+1):(n+1)*16)) = probePerm;
end

[trialList' probeList']

for n = 1:Ntrials
  fprintf(fid,'%i %i\n',trialList(n)-1,probeList(n)-1);
end
