function behavioralFGS(subject,isiEEG)
% function behavioralFGS(subject)
%
% This function will output basic behavioral analyses for the
% subject that is entered
% INPUT Args:
%  subject = 'FGS034'   - subject code
% isiEEG = 1            - whether this is iEEG data (for
% face-letter Sternberg)


if isiEEG
  basedir = '~/eeg/ieeg_mms';
else
  basedir= '~/mms/data';
end
eventsfile = 'beh/events.mat';
doGrating = 1;

figure(1)
fgs_stats_withLL2(basedir,{subject},eventsfile,3000,40,50,1);

evs = loadSubjEvents(basedir,{subject},eventsfile);

%remove practice trials if those are part of the struct
if isfield(evs,'ispractice') 
  cueEvs = filterStruct(evs,'strcmp(type,''CUE'') & RN~=-1 &~ispractice');
else
 cueEvs = filterStruct(evs,'strcmp(type,''CUE'') & RN~=-1'); 
end
numEvs = length(cueEvs);
allRTF = [];
allAccF = [];
xValF = [];
allRTG = [];
allAccG = [];
xValG = [];
for rn = 1:3
  thisEvsF = filterStruct(cueEvs,sprintf('RN==%d & strcmp(mode,''FACE'')',rn));
  thisEvsG = filterStruct(cueEvs,sprintf('RN==%d & (strcmp(mode,''GRATING'') | strcmp(mode,''LETTER''))',rn));
  rtsF = getStructField(thisEvsF,'rt');
  accsF = getStructField(thisEvsF,'correct');
  % compute mean rt and accuracy for this recent negative for faces
  RTmatF(rn) = mean(rtsF);
  accmatF(rn) = mean(accsF);
  RTvarF(rn) = sqrt(var(rtsF))/sqrt(length(rtsF));
  accVarF(rn) = sqrt(var(accsF))/sqrt(length(accsF));
  % add the actual data to an array so we can do a regression later
  allRTF = [allRTF; getStructField(thisEvsF,'rt')'];
  allAccF = [allAccF; getStructField(thisEvsF,'correct')'];
  xValF = [xValF; rn*ones(length(thisEvsF),1)];
  rtsG = getStructField(thisEvsG,'rt');
  accsG = getStructField(thisEvsG,'correct');
  % compute mean rt and acc for this recent negative for gratings
  RTmatG(rn) = mean(rtsG);
  accmatG(rn) = mean(accsG);
  RTvarG(rn) = sqrt(var(rtsG))/sqrt(length(rtsG));
  accVarG(rn) = sqrt(var(accsG))/sqrt(length(accsG));
  allRTG = [allRTG; getStructField(thisEvsG,'rt')'];
  allAccG = [allAccG; getStructField(thisEvsG,'correct')'];
  xValG = [xValG; rn*ones(length(thisEvsG),1)];  
end
% do regression within subject
xValF = [ones(length(xValF),1) xValF]; %introduce the constant term
                                      %in the design matrix
[bRTF,bint,r,rint,statsRTF] = regress(allRTF,xValF);
[bAccF,bint,r,rint,statsAccF] = regress(allAccF,xValF);
RTslopeF = bRTF(2);
accSlopeF = bAccF(2);
RTpvalF = statsRTF(3);
accPvalF = statsAccF(3);

if doGrating
  xValG = [ones(length(xValG),1) xValG]; %introduce the constant term
                                      %in the design matrix
  [bRTG,bint,r,rint,statsRTG] = regress(allRTG,xValG);
  [bAccG,bint,r,rint,statsAccG] = regress(allAccG,xValG);
  RTslopeG = bRTG(2);
  accSlopeG = bAccG(2);
  RTpvalG = statsRTG(3);
  accPvalG = statsAccG(3);
end

% plot the mean RN effect 
figure(2)
errorbar([1 2 3],RTmatG,RTvarG,'LineWidth',3);
hold on
errorbar([1 2 3],RTmatF,RTvarF,'r','LineWidth',3);
hold off
xlabel('lists back of probe')
ylabel('reaction time (ms)');
if ~isiEEG
  legend('grating','face')
else
  legend('letter','face')
end
set(gca,'XTick',[1 2 3]);
publishfig
figure(3)
errorbar([1 2 3],accmatG,accVarG,'LineWidth',3);
hold on
errorbar([1 2 3],accmatF,accVarF,'r','LineWidth',3);
hold off
xlabel('lists back of probe')
ylabel('accuracy');
set(gca,'YLim',[0 1.1]);
if ~isiEEG
  legend('grating','face')
else
  legend('letter','face')
end
set(gca,'XTick',[1 2 3]);
publishfig

fprintf('Recent negatives effect:\n');
if doGrating
  if isiEEG
    fprintf('   letters\n');
  else
    fprintf('   gratings\n');
  end
  fprintf('RT slope: %f (p=%f)\n',RTslopeG,RTpvalG);
  fprintf('acc slope: %f (p=%f)\n',accSlopeG,accPvalG);
end
fprintf('   faces\n');
fprintf('RT slope: %f (p=%f)\n',RTslopeF,RTpvalF);
fprintf('acc slope: %f (p=%f)\n',accSlopeF,accPvalF);


figure(4)
if isiEEG
  blockL = 15;
  numBlocks = 12;
else
  blockL=30;
  numBlocks = 10;
end


RTbyBlock = zeros(1,numBlocks);
accbyBlock = zeros(1,numBlocks);
if isfield(evs,'ispractice')
  cueEvs2 = filterStruct(evs,'strcmp(type,''CUE'') & ~ispractice');
else
  cueEvs2 = filterStruct(evs,'strcmp(type,''CUE'')');
end
allRTs = getStructField(cueEvs2,'rt');
allAccs = getStructField(cueEvs2,'correct');
for f=1:numBlocks
  RTbyBlock(f) = mean(allRTs((f-1)*blockL +1:f*blockL));
  accbyBlock(f) = mean(allAccs((f-1)*blockL + 1:f*blockL));
end

subplot(2,1,1)
bar(RTbyBlock)
xlabel('block')
ylabel('RT (ms)');
publishfig
subplot(2,1,2)
bar(accbyBlock)
xlabel('block')
ylabel('accuracy');
publishfig


% compute the set size functions
LLlist = unique(getStructField(cueEvs2,'listlen'));
accByLL_T = NaN(2,length(LLlist));
accByLLstd_T = NaN(2,length(LLlist));
RTByLL_T = NaN(2,length(LLlist));
RTByLLstd_T = NaN(2,length(LLlist));
accByLL_L = NaN(2,length(LLlist));
accByLLstd_L = NaN(2,length(LLlist));
RTByLL_L = NaN(2,length(LLlist));
RTByLLstd_L = NaN(2,length(LLlist));
for ll=1:length(LLlist)
  thisLLevsT = filterStruct(cueEvs2,sprintf('listlen==%d & rt>400 & rt<3000 & istarget',LLlist(ll)));
  allacc = getStructField(thisLLevsT,'correct');
  allrt = getStructField(thisLLevsT,'rt');
  mode = getStructField(thisLLevsT,'mode');
  moden = zeros(1,length(mode));
  for m = 1:length(mode)
    if strcmp(mode{m},'FACE')
      moden(m) = 1;
    else
      moden(m) = 2; %grating or letter
    end
  end
  if ~isempty(find(moden==1))
    accByLL_T(1,ll) = mean(allacc(find(moden==1)));
    accByLLstd_T(1,ll) = std(allacc(find(moden==1)));  
    RTByLL_T(1,ll) = mean(allrt(find(moden==1)));
    RTByLLstd_T(1,ll) = std(allrt(find(moden==1)));
  end
  if ~isempty(find(moden==2))
    accByLL_T(2,ll) = mean(allacc(find(moden==2)));
    accByLLstd_T(2,ll) = std(allacc(find(moden==2)));
    RTByLL_T(2,ll) = mean(allrt(find(moden==2)));
    RTByLLstd_T(2,ll) = std(allrt(find(moden==2)));  
  end
  thisLLevsL = filterStruct(cueEvs2,sprintf('listlen==%d & rt>400 & rt<3000 & ~istarget',LLlist(ll)));
  allacc = getStructField(thisLLevsL,'correct');
  allrt = getStructField(thisLLevsL,'rt');
  mode = getStructField(thisLLevsL,'mode');
  moden = zeros(1,length(mode));
  for m = 1:length(mode)
    if strcmp(mode{m},'FACE')
      moden(m) = 1;
    else
      moden(m) = 2; %grating or letter
    end
  end  
  isCorrect = getStructField(thisLLevsL,'correct');
  % compute set size function for faces
  if ~isempty(find(moden==1))
    accByLL_L(1,ll) = mean(allacc(find(moden==1)));
    accByLLstd_L(1,ll) = std(allacc(find(moden==1)));  
    RTByLL_L(1,ll) = mean(allrt(intersect(find(moden==1),find(isCorrect))));
    RTByLLstd_L(1,ll) = std(allrt(intersect(find(moden==1),find(isCorrect))));
  end
  % compute set size function for gratings/letters
  if ~isempty(find(moden==2))
    accByLL_L(2,ll) = mean(allacc(find(moden==2)));
    accByLLstd_L(2,ll) = std(allacc(find(moden==2)));
    RTByLL_L(2,ll) = mean(allrt(intersect(find(moden==2),find(isCorrect))));
    RTByLLstd_L(2,ll) = std(allrt(intersect(find(moden==2),find(isCorrect))));  
  end   
end

figure(5)
errorbar(LLlist,accByLL_T(1,:),accByLLstd_T(1,:),'r','LineWidth',3);
hold on
errorbar(LLlist,accByLL_L(1,:),accByLLstd_L(1,:),':r','LineWidth',3);
errorbar(LLlist+0.1,accByLL_T(2,:),accByLLstd_T(2,:),'LineWidth',3);
errorbar(LLlist+0.1,accByLL_L(2,:),accByLLstd_L(2,:),':','LineWidth',3);
hold off
xlabel('list length')
ylabel('accuracy');
legend('faceT','faceL','letterT','letterL','Location','SouthEast')
set(gca,'XTick',LLlist);
publishfig

figure(6)
errorbar(LLlist,RTByLL_T(1,:),RTByLLstd_T(1,:),'r','LineWidth',3);
hold on
errorbar(LLlist,RTByLL_L(1,:),RTByLLstd_L(1,:),'r:','LineWidth',3);
errorbar(LLlist+0.1,RTByLL_T(2,:),RTByLLstd_T(2,:),'LineWidth',3);
errorbar(LLlist+0.1,RTByLL_L(2,:),RTByLLstd_L(2,:),':','LineWidth',3);
hold off
xlabel('list length')
ylabel('reaction time (ms)');
legend('faceT','faceL','letterT','letterL','Location','SouthEast')
set(gca,'XTick',LLlist);
publishfig

%compute d-prime for faces and gratings
%for faces
%HR = istarget & correct; FA=~istarget & ~correct; d-prime=z(HR)-z(FA)
numTargF = length(filterStruct(cueEvs2,'strcmp(mode,''FACE'') & istarget'));
corrTargF = length(filterStruct(cueEvs2,'strcmp(mode,''FACE'') & istarget & correct'));
numLureF = length(filterStruct(cueEvs2,'strcmp(mode,''FACE'') & ~istarget'));
incorrLureF = length(filterStruct(cueEvs2,'strcmp(mode,''FACE'') & ~istarget & ~correct'));
dprimeF = norminv(corrTargF/numTargF) - norminv(incorrLureF/ ...
						numLureF);
fprintf('d-prime faces: %.03f\n',dprimeF);
%for gratings
numTargG = length(filterStruct(cueEvs2,'(strcmp(mode,''GRATING'')|strcmp(mode,''LETTER'')) & istarget'));
corrTargG = length(filterStruct(cueEvs2,'(strcmp(mode,''GRATING'')|strcmp(mode,''LETTER'')) & istarget & correct'));
numLureG = length(filterStruct(cueEvs2,'(strcmp(mode,''GRATING'')|strcmp(mode,''LETTER'')) & ~istarget'));
incorrLureG = length(filterStruct(cueEvs2,'(strcmp(mode,''GRATING'')|strcmp(mode,''LETTER'')) & ~istarget & ~correct'));
dprimeG = norminv(corrTargG/numTargG) - norminv(incorrLureG/ ...
						numLureG);
fprintf('d-prime gratings/letters: %.03f\n',dprimeG);
