function makeconfigEasy2
% create a config file for Faces using the faceLists structure,
% which provides info about the difficulty of the task

faceInfoFile = '~/mms/data/datFiles/faceListInfo.mat';
ll1InfoFile =  '~/mms/data/datFiles/faceLL1Info.mat';
blockOutFile = '~/pyFGS/easyBlockh.txt';

% reset the random number generator
rand('state',sum(100*clock)); 

load(faceInfoFile);
load(ll1InfoFile);
faceLists = [faceLists ll1Lists];
% allocate these lists so as to:
% 1) have equal numbers of targets and lures
% 2) have equal numbers of lists for each listlength (1,2 or 3)
% 3) have equal numbers of lists with each serial position
% 4) have the lure always come from 1, 2 or 3 lists ago
% separate these in blocks of 30 trials (each block starts to count
% the recent negatives anew)

% additional constraints:
% 1) study items not appeared in 2 preceding lists
% 2) if possible: lure appears only once in each block

numTrials = 180;
maxTime = 100; %maximum search time for list configuration
blockLength = 30;
numBlocks = numTrials/blockLength;
faceLists = filterStruct(faceLists,'listlen==1 | listlen==2 | listlen==3');
maxListNo = 700;

% decide on the set of lists to be used
grpLength = numTrials/12; %each list category has grpLength lists since there are 6 categories but numTrials/2 target trials
LL1grpT = filterStruct(faceLists,'listlen==1 & istarget');
LL1grpL = filterStruct(faceLists,'listlen==1 & ~istarget');
% no  lures for LL2????
LL2grpL = filterStruct(faceLists,'listlen==2 & ~istarget');
hlp = filterStruct(faceLists,'listlen==2 & istarget');
LL2SP1grp = filterStruct(hlp,'serpos==1');
LL2SP2grp = filterStruct(hlp,'serpos==2');
LL3grpL = filterStruct(faceLists,'listlen==3 & ~istarget');
hlp = filterStruct(faceLists,'listlen==3 & istarget');
LL3SP1grp = filterStruct(hlp,'serpos==1');
LL3SP2grp = filterStruct(hlp,'serpos==2');
LL3SP3grp = filterStruct(hlp,'serpos==3');
clear hlp

% sort the lists of all of these groups and pick the 30 lists for
% each category that are easiest
% LL1 (no difficulty info)
hlp = getStructField(LL1grpT,'listNo');
inds = randperm(length(hlp));
LL1grpT = LL1grpT(inds(1:blockLength));
hlp = getStructField(LL1grpL,'listNo');
inds = randperm(length(hlp));
LL1grpL = LL1grpL(inds(1:blockLength));
% LL2 (find lists with highest accuracy)
hlp = getStructField(LL2grpL,'difficulty');
[sorted,sortInd]=sort(hlp);
LL2grpL = LL2grpL(sortInd((end-blockLength+1):end));
hlp = getStructField(LL2SP1grp,'difficulty');
[sorted,sortInd]=sort(hlp);
LL2grpT = LL2SP1grp(sortInd((end+1-blockLength/2):end));
hlp = getStructField(LL2SP2grp,'difficulty');
[sorted,sortInd]=sort(hlp);
LL2grpT = [LL2grpT LL2SP2grp(sortInd((end+1-blockLength/2):end))];
% LL3
hlp = getStructField(LL3grpL,'difficulty');
[sorted,sortInd]=sort(hlp);
LL3grpL = LL3grpL(sortInd((end-blockLength+1):end));
hlp = getStructField(LL3SP1grp,'difficulty');
[sorted,sortInd]=sort(hlp);
LL3grpT = LL3SP1grp(sortInd((end+1-blockLength/3):end));
hlp = getStructField(LL3SP2grp,'difficulty');
[sorted,sortInd]=sort(hlp);
LL3grpT = [LL3grpT LL3SP2grp(sortInd((end+1-blockLength/3):end))];
hlp = getStructField(LL3SP3grp,'difficulty');
[sorted,sortInd]=sort(hlp);
LL3grpT = [LL3grpT LL3SP3grp(sortInd((end+1-blockLength/3):end))];
clear hlp
% now we have chosen the best lists, that we then have to put into
% an order that constrains the recent negative


% get the set of lists for all serial positions and list lengths
targlureBase = [zeros(numTrials/2,1) ones(numTrials/2,1)]; 
llBase = [ones(numTrials/3,1) 2*ones(numTrials/3,1) 3*ones(numTrials/3,1)];
% variable to keep track of which lists are already chosen

found = 0; %this variable indicates when to stop adding lists
while ~found %try another ll and target-lure sequence configuration
  targlureSeq = targlureBase(randperm(numTrials));
  %keyboard
  llSeq = llBase(randperm(numTrials));
  listsDone = zeros(1,maxListNo);
  listSeq = zeros(1,numTrials); % list numbers belonging to each trial
  seqInd = 1;
  b=1;
  newTry = 0;
  while b<=numBlocks & ~newTry 
    thisBlock = [];
    seqInd =(b-1)*blockLength+1; %which list we are trying to find
    % start filling in the lists for this block
    l=0;
    % if we have succeeded in making the previous list and we have
    % not yet completed the block, try to find the next list
    while (l<=blockLength) & ~newTry & ~found
      %keyboard
      l = l+1;
      % get all lists not yet done with desired LL and TL
      if targlureSeq(seqInd)==1 %we have to insert a target
	switch llSeq(seqInd) %check which list length is desired for the current trial
	 case 1
	  listSet = LL1grpT;
	 case 2
	  listSet = LL2grpT;
	 case 3
	  listSet = LL3grpT;
	end %switch case
        % try to find a list from the list set that has not yet
        % been done
	listFnd = 0;
	% try lists in a random order
	choice = randperm(length(listSet));
	t = 1;
	while ~listFnd & t <=length(listSet)
	  % we can use this list if it hasn't been done
	  if listsDone(listSet(choice(t)).listNo)==0 & ~repeatItems(listSet(choice(t)).listNo,listSeq,seqInd,faceLists,l)
	      listsDone(listSet(choice(t)).listNo) = 1;
	      listSeq(seqInd) = listSet(choice(t)).listNo;
	      listFnd=1;
	      thisBlock = [thisBlock listSeq(seqInd)];
          else
	    t = t+1;
	  end
        end
	% when we ended the previous cycle without finding a list,
        % we'll have to try a new set of list orders
	if ~listFnd
	  newTry=1;
	  % reset the list for this block
	  listsDone(thisBlock) = 0;
	  thisBlock = [];
	end
      else %we have to find a list with a lure
	switch llSeq(seqInd)
	 case 1
	  listSet = LL1grpL;
	 case 2
	  listSet = LL2grpL;
	 case 3
	  listSet = LL3grpL;
	end %switch
	% find a list that has not yet been chosen and which has a
        % lure from the list either 1,2 or 3 lists ago. If it
        % doesn't work, break out of the loop.
	listFits = 0;
	while ~listFits & ~newTry
	  % check whether this list is good
	  listAgo = randperm(3);
	  t = 1;
	  if (l-listAgo(t)) < 1
	      % we can choose any list from our listSet that has not
	      % been done
	      chooseList = ceil(length(listSet)*rand(1,1));
	      % keep choosing a different list until one is found
              % that was not done and does not have items that
              % repeat the previous two lists
	      while listsDone(listSet(chooseList).listNo) | repeatItems(listSet(chooseList).listNo,listSeq,seqInd,faceLists,l)
		chooseList = ceil(length(listSet)*rand(1,1)); 
		% choose another list
	      end  
	      listSeq(seqInd) = listSet(chooseList).listNo;
	      listsDone(listSet(chooseList).listNo) = 1;
	      thisBlock = [thisBlock listSeq(seqInd)];
	      listFits=1; %we have found a lits that fits
	  else
	    indFound = [];
	    while t<=3 & isempty(indFound) %try out all three recent
	    %negatives positions in random order
	      if (seqInd-listAgo(t)) < 1
		listAgoNo = listSeq(1);
	      else
		listAgoNo = listSeq(seqInd-listAgo(t));
	      end
	      thatList = filterStruct(faceLists,sprintf('listNo==%d',listAgoNo));
	      % loop through the list and see what items in the list
	      % have lure lists that have not yet been done
	      for li = 1:thatList(1).listlen
		switch li
		 case 1
		  thatItem = thatList.item1;
		 case 2
		  thatItem = thatList.item2;
		 case 3
		  thatItem = thatList.item3;
		end
		w = filterStruct(listSet,sprintf('probe==%d',thatItem));
		% pick the lists from here that were not done yet:
		wListNo = getStructField(w,'listNo');
		if ~isempty(w)
		  % get all the lists among those that have not yet
		  % been done
		  indFound = [indFound wListNo(find(listsDone(wListNo)==0))];
		end %now indFound contains all lists that could be used
	      end % for li=1:listlength
	      t = t+1;
	   end %while isempty(indFound)
	   if ~isempty(indFound)
		listFits = 1;
	      % choose one of the possible lists
	      chooseList = ceil(length(indFound*rand(1,1)));
	      listSeq(seqInd) = indFound(chooseList);
	      listsDone(indFound(chooseList)) = 1;
	      thisBlock = [thisBlock listSeq(seqInd)];
	   else
	      % we have to try to make this block again
	      newTry=1;
	      fprintf('r');
	      keyboard
	      % reset the list for this block
	      listsDone(thisBlock) = 0;
	      thisBlock = [];
	   end
	  end
	end %while ~listFits
      end % if target else lure
      fprintf('%d: %d\n',seqInd,listSeq(seqInd));
      %pause
      seqInd = seqInd +1;
      if (seqInd>numTrials)
	found = 1;
      end
    end %while (l<=blockLength) & ~newTry
      b = b+1;
  end % while ~found 
 end % while b<=numBlocks & ~newTry
 
 
% write the blocks to output file (based on listNo)
fid = fopen(blockOutFile,'w');
for n = 1:numTrials
  % if we are at the start of a new block, we have to insert a line
  % with block info
  if mod(n,blockLength)==1
    fprintf(fid,'* 1 0 1\n'); 
    %this means it's a face block, REAL and ...
  end
  thisList = filterStruct(faceLists,sprintf('listNo==%d',listSeq(n)));
  switch thisList.listlen
   case 1
    fprintf(fid,'%d %d\n',[thisList.item1 thisList.probe]);
   case 2
    fprintf(fid,'%d %d %d\n',[thisList.item1 thisList.item2 thisList.probe]);    
   case 3
    fprintf(fid,'%d %d %d %d\n',[thisList.item1 thisList.item2 ...
		    thisList.item3 thisList.probe]);
   end %switch thisList.listlen
end
% close the file again
fclose(fid);

%check whether any items from one of the two previous lists repeat
function itemsDone=repeatItems(tryListNo,listSeq,seqInd,faceLists,blockInd)
if blockInd==1
  itemsDone = 0;
elseif blockInd==2
  checkList = filterStruct(faceLists,sprintf('listNo==%d',listSeq(seqInd-1)));
  tryList = filterStruct(faceLists,sprintf('listNo==%d',tryListNo));
  doneItems = [tryList.item1 tryList.item2 tryList.item3];
  checkItems = [checkList.item1 checkList.item2 checkList.item3];
  if isempty(intersect(doneItems,checkItems))
    itemsDone =0;
  else
    itemsDone=1;
  end
else
  checkList1 = filterStruct(faceLists,sprintf('listNo==%d',listSeq(seqInd-1)));
  checkList2 = filterStruct(faceLists,sprintf('listNo==%d',listSeq(seqInd-2)));
  tryList = filterStruct(faceLists,sprintf('listNo==%d',tryListNo));
  doneItems = [tryList.item1 tryList.item2 tryList.item3];
  checkItems1 = [checkList1.item1 checkList1.item2 checkList1.item3];
  checkItems = [checkItems1 checkList2.item1 checkList2.item2 checkList2.item3];
  if isempty(intersect(doneItems,checkItems))
    itemsDone =0;
  else
    itemsDone=1;
  end  
end
