#!/usr/bin/python
# -*- coding: utf8 -*-

# Instructions to the user: after the practice trials you can press the key specified by endPracticeKey in the config file to continue with the real trials
# This version of the script makes use of the TextPool/ImagePool

# import PyEPL symbols into this namespace
from pyepl.locals import *
# use the random module to randomize the jitter
import random
import sys
import os

from translations import instructions

# set the current version
VERSION = '1.0.4'


def prepare(exp,config):
    """
    This function determines the stimulus sequence, as well 
    as all kind of initial values.
    """
    # get the state
    state = exp.restoreState() 

    sessionList = []

    for sessionNum in xrange(config.numSessions):
        # set the session so we know the correct directory
        exp.setSession(sessionNum)
        
	sessionconfig = config.sequence(sessionNum)
	# read the blocks from the file
        blockList = sessionconfig.blocks
        trialBlocks = []
        blockNum = 0

        #while blockNum < len(blockList):
        while blockNum < sessionconfig.numBlocks:
        # start with an empty list for the trials
	    trialList = []
	    thisBlock = blockList[blockNum]
            stimulusSet = config.modeStimDict[thisBlock.mode]
	    # for each trial
	    for trialNum in xrange(len(thisBlock.seq)):
		# get trial specific configuration
		#trialconfig = sessionconfig.thisBlock.seq(trialNum)
		# append stimulus n to the trial list; we first get the row for this trial (note that matrix indices for Python start at 0
                thisTrialInd  = thisBlock.seq[trialNum]
		thisTrial = []
		
		for eachIm in thisTrialInd:
		    #thisTrial.append(sessionconfig.faceStimuli.findBy(num=eachIm))
                    thisTrial.append(stimulusSet[eachIm])
		
		#add the just-constructed trial to the trialList
		trialList.append(thisTrial)
           
            # add the trial list to the list with blocks
            trialBlocks.append(trialList)
            blockNum += 1
		
	sessionList.append(trialBlocks)

    exp.saveState(None,trialNum = 0, sessionList = sessionList, blockNum = 0, sessionNum = 0)


def run(exp,config):
    """
    Present lists of stimuli in different modalities, requires 
    the subject to respond whether the stimulus was in the list (standard
    Sternberg task), where stimuli can be from different classes 
    (modalities).  After each trial, feedback can be given if desired,
    after each block, global accuracy and RT feedback will be given
    """
    # get the state
    state = exp.restoreState()

    #set up session
    if state.sessionNum >= len(state.sessionList):
        # if all the sessions have been run, do not continue
        print "No more sessions!"
        return
    
    # set the session number
    exp.setSession(state.sessionNum)
    
    #get session specific configuration
    sessionconfig = config.sequence(state.sessionNum)

    # get the instructions in the configured language
    txt = instructions(config.language)

    # create tracks
    video = VideoTrack("video")
    keyboard = KeyTrack("keyboard")
    log = LogTrack("session")

    # define keys
    targetKey = config.targetKey
    lureKey = config.lureKey
    endPracticeKey = config.endPracticeKey
    minDuration = 100
    bc = ButtonChooser(Key(targetKey),Key(lureKey))
    endPractice = ButtonChooser(Key(endPracticeKey))
    endReal = ButtonChooser(Key(endPracticeKey))
    endBlock = ButtonChooser(Key(config.endBlockKey))
    choosePractice = ButtonChooser(Key("Y"),Key("N"));

    # create a presentation clock to handle timing
    clock = PresentationClock()

    # log the start of the session
    log.logMessage('%s\t%d' % ('SESS_START',state.sessionNum),clock)

    # if we're on the first block of a session, display instructions
    if state.blockNum == 0:
        if (state.sessionNum > 0) and (config.isHospital):
	    video.clear(sessionconfig.backgroundcol)
            stim = Text("Do face practice? (Y/N)",color=(0,0,0),size=sessionconfig.textSize)
	    timestamp,button,rt = stim.present(clock,sessionconfig.MAXP,0,bc=choosePractice,minDuration=minDuration)
            if (button == Key("N")):
		state.blockNum = 1    
        # only if this is the first block of a session will we initialize
        # the accuracy and rt to zero
        state.acc = 0
        state.rt = 0
	# this variable keeps track of how many REAL sessions the
	# subject has had (so does not count the practice sessions)
	state.realBlockNum = 0
        state.trialNum = 0
        state.numCorrect = 0.0
        state.sumRT = 0

        video.clear(sessionconfig.backgroundcol)
        instruct(sessionconfig.instructions,color=(0,0,0),size=sessionconfig.textSize)
        
    while state.blockNum < len(state.sessionList[state.sessionNum]):
        giveFeedback = sessionconfig.blocks.findBy(num=state.blockNum+1).feedback
        modeString = sessionconfig.blocks.findBy(num=state.blockNum+1).mode
        BlockIsPractice = sessionconfig.blocks.findBy(num=state.blockNum+1).ispractice
        if BlockIsPractice:
            practiceRealStr = 'PRACTICE'
        else:
            practiceRealStr = 'REAL'        

        # present each trial
        while state.trialNum < len(state.sessionList[state.sessionNum][state.blockNum]):
           
	    # log the start of a trial
	    log.logMessage('%s\t%d' % ('TRIAL',state.trialNum+1))
	
	    # get trial specific configuration
	    trialconfig = sessionconfig.sequence(state.trialNum)
	
	    # clear instructions/previous trial
            video.clear(sessionconfig.backgroundcol)
    
	    # wait for a key to be pressed
	    if config.isHospital:
	       waitForAnyKey(clock, Text(txt['PressAnyKey'] ,color=(0,0,0),size=sessionconfig.textSize))		
	    else:
	       waitForAnyKey(clock, Text(txt["BlinkNow"] ,color=(0,0,0),size=sessionconfig.textSize))

	    # display fixation cross
            clock.delay(sessionconfig.D1,sessionconfig.JITTER)
	    video.showCentered(Text("*", size=0.1,color=(0,0,0)))
	    video.updateScreen(clock)
	    clock.delay(sessionconfig.D2)
            video.clear(sessionconfig.backgroundcol)
	    clock.delay(sessionconfig.D3,sessionconfig.JITTER)

            n = 0
            thisList = []
            timesList = []
            imFileNameList = []
            listlength = len(state.sessionList[state.sessionNum][state.blockNum][state.trialNum])-1
            while n < listlength:
	        # get image-specific configuration
	        imconfig = trialconfig.sequence(n)
	        # present the image
	        eachImage = state.sessionList[state.sessionNum][state.blockNum][state.trialNum][n]
	        eachImage.content.loadRequireCount = 1
                timestamp = eachImage.content.present(clock,sessionconfig.PR,sessionconfig.JITTER)
                # save some data for logging purposes
                timesList.append(timestamp)
                thisList.append(eachImage.name)
                imFileNameList.append(eachImage.name)
                
                video.clear(sessionconfig.backgroundcol)
	        n += 1
	        if (n < (len(state.sessionList[state.sessionNum][state.blockNum][state.trialNum])-1)):
	            clock.delay(sessionconfig.ISI,sessionconfig.JITTER)
	
            # delay 
            video.clear(sessionconfig.backgroundcol)
            clock.delay(sessionconfig.D4 ,sessionconfig.JITTER2)

            # show probe stimulus and wait for response
            probeImage = state.sessionList[state.sessionNum][state.blockNum][state.trialNum][n]
            probeImage.content.loadRequireCount = 1
            prestime,button,bc_time = probeImage.content.present(clock,sessionconfig.MAXP,sessionconfig.JITTER,bc=bc,minDuration=minDuration)
            probeFile = probeImage.name
            reaction_time = bc_time[0]-prestime[0]
            state.sumRT = state.sumRT + reaction_time
            # give feedback: CORRECT! or INCORRECT
            istarget = probeImage.name in thisList
            if (istarget and (button.name == targetKey)) or ((not istarget) and (button.name == lureKey)):
                iscorrect = 1
            else:
                iscorrect = 0
            state.numCorrect = state.numCorrect + iscorrect
	    if giveFeedback:
                if iscorrect:
                    video.showCentered(Text(txt["Correct"],color=(0,0,0),size=sessionconfig.textSize))
                    video.updateScreen(clock)
                    clock.delay(sessionconfig.D5)
                else:
                    video.showCentered(Text(txt["Incorrect"],color=(0,0,0),size=sessionconfig.textSize))
                    video.updateScreen(clock)
                    clock.delay(sessionconfig.D5)           

            video.clear(sessionconfig.backgroundcol)
            
            # write the results to the log file (which couldn't be done earlier because we did not know the RT and accuracy)
            # determine the position in the list from which the probe was drawn
            if istarget:
                probePos = thisList.index(probeImage.name) + 1
                targetStr = "Target"
            else:
                probePos = 0
                targetStr = "Lure"
            # make a string for the correctness for easier logging
            if iscorrect:
                correctStr = "Correct"
            else:
                correctStr = "Incorrect"
            n = 0
            while (n < listlength):
                log.logMessage('%s\t%d\tPRES%d_%s\t%s\tLL%d\tPP%d\t%s_%s\t0\t%s' % (modeString,reaction_time,(n+1),imFileNameList[n],correctStr,listlength,probePos,targetStr,probeFile,practiceRealStr),timesList[n])
                n += 1
            log.logMessage('%s\t%d\tCUE\t%s\tLL%d\tPP%d\t%s_%s\t0\t%s' % (modeString,reaction_time,correctStr,listlength,probePos,targetStr,probeFile,practiceRealStr),prestime)
            log.logMessage('%s\t%d\tRESP\t%s\tLL%d\tPP%d\t%s_%s\t0\t%s' % (modeString,reaction_time,correctStr,listlength,probePos,targetStr,probeFile,practiceRealStr),bc_time)
            clock.delay(300) # wait after having shown the block's results
            
            # save the state after each trial
            exp.saveState(state)
	    # move to the next trial
	    state.trialNum += 1


        meanCorrect = state.numCorrect/state.trialNum
        meanRT = state.sumRT/state.trialNum
        if BlockIsPractice:
            video.showCentered(Text(txt["Congratulations"] % (state.blockNum + 1,meanCorrect*100,meanRT),color=(0,0,0),size=sessionconfig.textSize ))
            video.updateScreen(clock)
	    endBlock.waitChoice(10,sessionconfig.MAXP,clock)
            video.clear(sessionconfig.backgroundcol)
            # if we're at the end of the block, we set the trial number to 0
	    state.trialNum = 0
	    state.numCorrect = 0.0
	    state.sumRT = 0
        else:
            video.showCentered(Text(txt["Congratulations"] % (state.realBlockNum + 1,meanCorrect*100,meanRT),color=(0,0,0),size=sessionconfig.textSize ))
            video.updateScreen(clock)
            endBlock.waitChoice(10,sessionconfig.MAXP,clock)
            video.clear(sessionconfig.backgroundcol)
            state.realBlockNum += 1
            state.acc = state.acc + meanCorrect
            state.rt = state.rt + meanRT
            # if we're at the end of the block, we set the trial number to 0
	    state.trialNum = 0
	    state.numCorrect = 0.0
	    state.sumRT = 0

	state.blockNum += 1
        # if it's the end of the practice segment, show a message
        if state.blockNum == len(state.sessionList[state.sessionNum]):
            video.showCentered(Text(txt["ThankYou"], color=(0,0,0),size=sessionconfig.textSize))
            video.updateScreen(clock)
            endReal.waitChoice(10,sessionconfig.MAXP,clock)
            video.clear(sessionconfig.backgroundcol)
        elif (BlockIsPractice == 1) and (sessionconfig.blocks.findBy(num=state.blockNum+1).ispractice == 0):
                video.showCentered(Text(txt["FinishedPractice"],color=(0,0,0),size=sessionconfig.textSize))
                numPracticeTrials = state.trialNum
                video.updateScreen(clock)
                endPractice.waitChoice(10,sessionconfig.MAXP,clock)
                video.clear(sessionconfig.backgroundcol)

    # log the end of the session
    log.logMessage('%s\t%d' % ('SESS_END',state.sessionNum+1),clock)

    if not config.isAssoc:
	if config.isHospital:
	    numRealBlocks = 12
	else:
	    numRealBlocks = config.numBlocks-2
	    waitForAnyKey(clock,Text(txt["AvgAccRT"] % (state.acc/numRealBlocks,state.rt/numRealBlocks),color=(0,0,0),size=sessionconfig.textSize))    
    
    #save the state when the session is finished with trial and session numbers set for the next session
    exp.saveState(state, trialNum=0, sessionNum = state.sessionNum + 1,blockNum=0);

    # wait for the clock to catch up 
    clock.wait()

# if the experiment is run as a stand-alone program (not as a library)
if __name__ == "__main__":
        # check pyepl version
        checkVersion('1.0.6')
	# set up the experiment
	exp = Experiment()
	# the line below parses the command line options for the experiment
	exp.parseArgs()
	exp.setup()
	
	# allow the users to break out of the experiment with ESC-F1
	exp.setBreak()
	
	# get the subject configuration
	config = exp.getConfig()
	
	# if there was no saved state, run the prepare function
	if not exp.restoreState():
		prepare(exp,config)
		
	# now run the subject
	run(exp,config)
